pyramid_uniform - Form handling for Pyramid
===========================================

Scott Torborg - `Cart Logic <http://www.cartlogic.com>`_

Form rendering and validation for Pyramid. Doesn't render HTML itself, so you
have full control over form markup.

Heavily inspired by the ``pyramid_simpleform`` package, with some fixes and
updates to work with WebHelpers2 and Python 3.


Installation
============

Install with pip::

    $ pip install pyramid_uniform


License
=======

pyramid_uniform is licensed under an MIT license. Please see the LICENSE file
for more information.
